==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ru.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Обзор использования",
    "Sent on: {on}" : "Отправлено: {on}",
    "An error occurred while sending your report." : "При отправке вашего отчёта произошла ошибка.",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Список приложений <em>(для каждого из приложений: его название, версия, включено или нет)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Информация о БД <em>(тип, версия, размер)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информация о применяемом шифровании <em>(используется ли, применяемый по умолчанию модуль)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Количество общих ресурсов <em>(по типу и настройкам доступа)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Информация о PHP <em>(версия, лимит памяти, макс. выполнения, макс. размер файла)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Подробности установки сервера <em>(версия, использование memcache, использование блокировок/пред.просмотра/аватаров)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Статистика <em>(количества: файлов, пользователей, хранилищ по их типам, комментариев и меток)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. Отключить передачу данных можно в любое время в настройках администратора.",
    "Not now" : "Не сейчас",
    "Send usage" : "Отправить информацию об использовании",
    "Never" : "Никогда",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Мы серьёзно относимся к соблюдению конфиденциальности. По умолчанию отправка данных отключена, и если вы решите включить ее, в первую очередь она будет анонимной, а так же вы сможете выбрать, какими именно данными вы будете делиться. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Отправьте пустой отчёт что бы удалить все данные, хранящиеся на сервере.",
    "Send new report now" : "Отправить отчёт сейчас",
    "Send usage survey monthly" : "Отправлять информацию об использовании ежемесячно",
    "Data to send" : "Данные для отправки",
    "Last report" : "Последний отчёт",
    "Sent on: %s" : "Отправлен: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Мы серьёзно относимся к соблюдению конфиденциальности. Данные обезличенны, вы можете включить / отключить их передачу в любое время, по умолчанию передача всегда отключена. Ниже можно настроить, какие именно данные будут отправляться, и всегда видеть последний отправленный нам отчёт. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Если вы отключите один из приведённых ниже параметров, вы можете отправить новый отчёт, который удалит данные, хранящиеся на нашем сервере.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Мы серьёзно относимся к соблюдению конфиденциальности. Данные обезличенны, вы можете включить / отключить их передачу в любое время, по умолчанию передача всегда отключена. Ниже можно настроить, какие именно данные будут отправляться, и всегда видеть последний отправленный нам отчёт. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Если вы отключите один из приведённых ниже параметров, вы можете отправить новый отчёт, который удалит данные, хранящиеся на нашем сервере."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ru.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Обзор использования",
    "Sent on: {on}" : "Отправлено: {on}",
    "An error occurred while sending your report." : "При отправке вашего отчёта произошла ошибка.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Список приложений <em>(для каждого из приложений: его название, версия, включено или нет)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Информация о БД <em>(тип, версия, размер)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информация о применяемом шифровании <em>(используется ли, применяемый по умолчанию модуль)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Количество общих ресурсов <em>(по типу и настройкам доступа)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Информация о PHP <em>(версия, лимит памяти, макс. выполнения, макс. размер файла)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Подробности установки сервера <em>(версия, использование memcache, состояние блокировок / пред. просмотра / аватаров)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Статистика <em>(количества: файлов, пользователей, хранилищ по их типам, комментариев и меток)</em>",
    "Help improve Nextcloud" : "Помогайте улучшать Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. Отключить передачу данных можно в любое время в настройках администратора.",
    "Not now" : "Не сейчас",
    "Send usage" : "Отправить информацию об использовании",
    "Never" : "Никогда",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Мы серьёзно относимся к соблюдению конфиденциальности. По умолчанию отправка данных отключена, и если вы решите включить ее, в первую очередь она будет анонимной, а так же вы сможете выбрать, какими именно данными вы будете делиться. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Отправьте пустой отчёт что бы удалить все данные, хранящиеся на сервере.",
    "Send new report now" : "Отправить отчёт сейчас",
    "Send usage survey monthly" : "Отправлять информацию об использовании ежемесячно",
    "Data to send" : "Данные для отправки",
    "Last report" : "Последний отчёт",
    "Sent on: %s" : "Отправлен: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Список приложений <em>(для каждого из приложений: его название, версия, включено или нет)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Подробности установки сервера <em>(версия, использование memcache, использование блокировок/пред.просмотра/аватаров)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Мы серьёзно относимся к соблюдению конфиденциальности. Данные обезличенны, вы можете включить / отключить их передачу в любое время, по умолчанию передача всегда отключена. Ниже можно настроить, какие именно данные будут отправляться, и всегда видеть последний отправленный нам отчёт. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Если вы отключите один из приведённых ниже параметров, вы можете отправить новый отчёт, который удалит данные, хранящиеся на нашем сервере.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Предоставляя обезличенную информацию о своих настройках и статистике использования, Вы помогаете нам улучшить Nextcloud. ",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Мы серьёзно относимся к соблюдению конфиденциальности. Данные обезличенны, вы можете включить / отключить их передачу в любое время, по умолчанию передача всегда отключена. Ниже можно настроить, какие именно данные будут отправляться, и всегда видеть последний отправленный нам отчёт. Когда сервер получает новый отчёт, все записи предыдущих отчётов удаляются. Если вы отключите один из приведённых ниже параметров, вы можете отправить новый отчёт, который удалит данные, хранящиеся на нашем сервере."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
